@@ -1,5 +1,3 @@
-# Copyright (c) 2016. Mount Sinai School of Medicine
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -15,13 +13,14 @@
 from __future__ import print_function, division, absolute_import
 
 from collections import defaultdict
-import logging
 
 from six.moves import range
 
 from .default_parameters import MIN_VARIANT_SEQUENCE_ASSEMBLY_OVERLAP_SIZE
+from .logging import get_logger
+
+logger = get_logger(__name__)
 
-logger = logging.getLogger(__name__)
 
 def greedy_merge_helper(
         variant_sequences,
@@ -41,7 +40,7 @@ def greedy_merge_helper(
         # arguments if sequence1 is on the right of sequence2
         for j in range(i + 1, len(variant_sequences)):
             sequence2 = variant_sequences[j]
-            combined = sequence1.combine(sequence2)
+            combined = sequence1.combine(sequence2, min_overlap_size=min_overlap_size)
             if combined is None:
                 continue
             if combined.sequence in merged_variant_sequences:
@@ -56,6 +55,7 @@ def greedy_merge_helper(
     result = list(merged_variant_sequences.values()) + list(unmerged_variant_sequences)
     return result, merged_any
 
+
 def greedy_merge(
         variant_sequences,
         min_overlap_size=MIN_VARIANT_SEQUENCE_ASSEMBLY_OVERLAP_SIZE):
@@ -74,6 +74,7 @@ def greedy_merge(
             min_overlap_size=min_overlap_size)
     return variant_sequences
 
+
 def collapse_substrings(variant_sequences):
     """
     Combine shorter sequences which are fully contained in longer sequences.
@@ -114,6 +115,7 @@ def collapse_substrings(variant_sequences):
         for variant_sequence in result_list
     ]
 
+
 def iterative_overlap_assembly(
         variant_sequences,
         min_overlap_size=MIN_VARIANT_SEQUENCE_ASSEMBLY_OVERLAP_SIZE):
