@@ -1,5 +1,3 @@
-# Copyright (c) 2016. Mount Sinai School of Medicine
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -51,14 +49,6 @@ USE_SECONDARY_ALIGNMENTS = True
 # number of nucleotides to extract from RNAseq reads around each variant
 VARIANT_SEQUENCE_LENGTH = 90
 
-# number of nucleotides to the left and right of a variant to extract,
-# usually gets adjusted for variant length but some functions take this
-# parameter directly
-CDNA_CONTEXT_SIZE = VARIANT_SEQUENCE_LENGTH // 2
-
-# minimum number of total RNA reads supporting a variant allele
-MIN_ALT_RNA_READS = 2
-
 # minimum number of reads supporting each nucleotide of a
 # variant coding sequence
 MIN_VARIANT_SEQUENCE_COVERAGE = 2
@@ -73,7 +63,7 @@ MAX_REFERENCE_TRANSCRIPT_MISMATCHES = 2
 
 # whether to include mismatches after a variant locus toward the
 # MAX_REFERENCE_TRANSCRIPT_MISMATCHES count
-INCLUDE_MISMATCHES_AFTER_VARIANT = False
+COUNT_MISMATCHES_AFTER_VARIANT = False
 
 # number of amino acids / codons we're trying to translate
 PROTEIN_SEQUENCE_LENGTH = 20
@@ -91,3 +81,55 @@ VARIANT_SEQUENCE_ASSEMBLY = False
 # to minimize false assembly of isoforms which don't
 # actually exist.
 MIN_VARIANT_SEQUENCE_ASSEMBLY_OVERLAP_SIZE = 30
+
+# include sequences from reads if they were clipped
+# by the aligner
+USE_SOFT_CLIPPED_BASES = False
+
+# minimum number of RNA reads supporting a variant allele
+MIN_NUM_RNA_ALT_READS = 3
+
+# minimum number of total RNA fragments supporting a variant allele,
+# differs from MIN_NUM_ALT_READS for paired end sequencing but is the same
+# for single-end sequencing
+MIN_NUM_RNA_ALT_FRAGMENTS = 2
+
+# minimum ratio of # alt reads / # total overlapping reads
+MIN_FRACTION_RNA_ALT_READS = 0.005  # (at least e.g. 3 in 600)
+
+# minimum ratio of # alt fragments / # total overlapping fragments
+MIN_FRACTION_RNA_ALT_FRAGMENTS = 0.005  # (at least e.g. 3 in 600)
+
+# maximum number of RNA reads supporting a reference allele
+MAX_NUM_RNA_REF_READS = 10 ** 9
+
+# maximum number of total RNA fragments supporting a reference allele
+MAX_NUM_RNA_REF_FRAGMENTS = 10 ** 9
+
+# minimum ratio of # ref reads / # total overlapping reads
+MAX_FRACTION_RNA_REF_READS = 1.0
+
+# minimum ratio of # ref fragments / # total overlapping fragments
+MAX_FRACTION_RNA_REF_FRAGMENTS = 1.0
+
+# maximum number of RNA reads supporting a reference allele
+MAX_NUM_RNA_OTHER_READS = 10 ** 9
+
+# maximum number of total RNA fragments supporting a reference allele
+MAX_NUM_RNA_OTHER_FRAGMENTS = 10 ** 9
+
+# minimum ratio of # other (non-ref/non-alt) reads / # total overlapping reads
+MAX_FRACTION_RNA_OTHER_READS = 0.5
+
+# minimum ratio of # other fragments (non-ref/non-alt) / # total overlapping fragments
+MAX_FRACTION_RNA_OTHER_FRAGMENTS = 0.5
+
+# At loci where there is RNA support for both the alt allele and other
+# non-reference alleles, we want the number of reads supporting the alt
+# to be at least this many times greater than the total counts for the
+# third and fourth alleles.
+MIN_RATIO_RNA_ALT_TO_OTHER_FRAGMENTS = 3.0
+
+# number of RNA fragments shared between two assembled protein sequences
+# before we say that their variants are phased
+MIN_SHARED_FRAGMENTS_FOR_PHASING = 2
\ No newline at end of file
