@@ -1,5 +1,3 @@
-# Copyright (c) 2016. Mount Sinai School of Medicine
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -14,6 +12,11 @@
 
 from __future__ import print_function, division, absolute_import
 
+"""
+This module implements basic DNA functionality in Python strings to
+to avoid having to depend on a bigger library such as BioPython.
+"""
+
 dna_complement_dictionary = {
     "A": "T",
     "T": "A",
@@ -27,8 +30,28 @@ dna_nucleotide_to_index = {c: i for (i, c) in enumerate(dna_nucleotides)}
 
 index_to_dna_nucleotide = {i: c for (i, c) in enumerate(dna_nucleotides)}
 
+
 def complement_dna(seq):
+    """
+    Convert every A->T, T->A, C->G, G->C in a DNA sequence
+
+    Parameters
+    ----------
+    seq : str
+
+    Returns str
+    """
     return "".join(dna_complement_dictionary[nt] for nt in seq)
 
+
 def reverse_complement_dna(seq):
+    """
+    Reverse complement of a DNA sequence
+
+    Parameters
+    ----------
+    seq : str
+
+    Returns str
+    """
     return complement_dna(seq)[::-1]
