@@ -1,5 +1,3 @@
-# Copyright (c) 2016. Mount Sinai School of Medicine
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -17,11 +15,13 @@ Helper functions for normalizing and working with genomic variants
 """
 
 from __future__ import print_function, division, absolute_import
-import logging
 
 from six.moves import range
+from .logging import get_logger
+from .dna import reverse_complement_dna
+
+logger = get_logger(__name__)
 
-logger = logging.getLogger(__name__)
 
 def trim_variant_fields(location, ref, alt):
     """
@@ -123,6 +123,7 @@ def base0_interval_for_variant(variant):
         ref=ref,
         alt=alt)
 
+
 def interbase_range_affected_by_variant_on_transcript(variant, transcript):
     """
     Convert from a variant's position in global genomic coordinates on the
@@ -141,13 +142,10 @@ def interbase_range_affected_by_variant_on_transcript(variant, transcript):
     which indicates which bases in the reference sequence are affected by a
     variant.
 
-    Example:
-        The insertion of "TTT" into the middle of an exon would result in an
-        offset pair such as (100,100) since no reference bases are changed
-        or deleted by an insertion.
-
-        On the other hand, deletion the preceding "CGG" at that same locus could
-        result in an offset pair such as (97, 100)
+    For example, the insertion of "TTT" into the middle of an exon would result in an
+    offset pair such as (100,100) since no reference bases are changed or deleted by
+    an insertion. On the other hand, deletion the preceding "CGG" at that same locus could
+    result in an offset pair such as (97, 100)
     """
     if variant.is_insertion:
         if transcript.strand == "+":
@@ -187,3 +185,13 @@ def interbase_range_affected_by_variant_on_transcript(variant, transcript):
         start_offset = min(offsets)
         end_offset = max(offsets) + 1
     return (start_offset, end_offset)
+
+
+def variant_matches_reference_sequence(variant, ref_seq_on_transcript, strand):
+    """
+    Make sure that reference nucleotides we expect to see on the reference
+    transcript from a variant are the same ones we encounter.
+    """
+    if strand == "-":
+        ref_seq_on_transcript = reverse_complement_dna(ref_seq_on_transcript)
+    return ref_seq_on_transcript == variant.ref
