@@ -1,25 +1,13 @@
-# Copyright (c) 2016. Mount Sinai School of Medicine
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 from __future__ import print_function, division, absolute_import
 
-from isovar.read_helpers import group_unique_sequences
-from isovar.variant_reads import reads_supporting_variant
+from isovar import ReadCollector
+from isovar.allele_read_helpers import  group_unique_sequences
+
 from varcode import Variant
-from pyensembl import ensembl_grch38
 
 from testing_helpers import load_bam
+from genomes_for_testing import grch38
+
 
 def test_group_unique_sequences():
     samfile = load_bam("data/cancer-wgs-primary.chr12.bam")
@@ -31,10 +19,10 @@ def test_group_unique_sequences():
         contig=chromosome,
         start=base1_location,
         ref=ref, alt=alt,
-        ensembl=ensembl_grch38)
-    variant_reads = reads_supporting_variant(
-        samfile=samfile,
-        chromosome=chromosome,
+        ensembl="hg38")
+    read_collector = ReadCollector()
+    variant_reads = read_collector.allele_reads_supporting_variant(
+        alignment_file=samfile,
         variant=variant)
     print("%d variant reads: %s" % (
         len(variant_reads), variant_reads))
