@@ -1,30 +1,18 @@
-# Copyright (c) 2016. Mount Sinai School of Medicine
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 from __future__ import print_function, division, absolute_import
 
-from isovar.reference_sequence_key import ReferenceSequenceKey
 from varcode import Variant
-from pyensembl import ensembl_grch38, genome_for_reference_name
 from nose.tools import eq_
 
+from isovar.reference_sequence_key import ReferenceSequenceKey
+
+from genomes_for_testing import grch38, grcm38
+
+
 def test_sequence_key_for_variant_on_transcript_substitution():
     # rs769125639 is a simple T>A substitution in the 6th nucleotide of
     # BRCA2-001's 5' UTR
-    brca2_variant_rs769125639 = Variant(
-        "13", 32315479, "T", "A", ensembl_grch38)
-    brca2_001 = ensembl_grch38.transcripts_by_name("BRCA2-001")[0]
+    brca2_variant_rs769125639 = Variant("13", 32315479, "T", "A", grch38)
+    brca2_001 = grch38.transcripts_by_name("BRCA2-001")[0]
     # first 50 characters of BRCA2-001:
     #  "GGGCTTGTGGCGCGAGCTTCTGAAACTAGGCGGCAGAGGCGGAGCCGCTG"
     brca2_ref_seq = brca2_001.sequence[:50]
@@ -45,9 +33,8 @@ def test_sequence_key_for_variant_on_transcript_substitution():
 
 def test_sequence_key_for_variant_on_transcript_deletion():
     # Delete the 6th nucleotide of BRCA2-001's 5' UTR
-    brca2_variant_deletion = Variant(
-        "13", 32315479, "T", "", ensembl_grch38)
-    brca2_001 = ensembl_grch38.transcripts_by_name("BRCA2-001")[0]
+    brca2_variant_deletion = Variant("13", 32315479, "T", "", grch38)
+    brca2_001 = grch38.transcripts_by_name("BRCA2-001")[0]
     # first 50 characters of BRCA2-001:
     #  "GGGCTTGTGGCGCGAGCTTCTGAAACTAGGCGGCAGAGGCGGAGCCGCTG"
     brca2_ref_seq = brca2_001.sequence[:50]
@@ -65,11 +52,12 @@ def test_sequence_key_for_variant_on_transcript_deletion():
         sequence_after_variant_locus=brca2_ref_seq[6:16])
     eq_(sequence_key, expected_sequence_key)
 
+
 def test_sequence_key_for_variant_on_transcript_insertion():
     # Insert 'CCC' after the 6th nucleotide of BRCA2-001's 5' UTR
     brca2_variant_insertion = Variant(
-        "13", 32315479, "T", "TCCC", ensembl_grch38)
-    brca2_001 = ensembl_grch38.transcripts_by_name("BRCA2-001")[0]
+        "13", 32315479, "T", "TCCC", grch38)
+    brca2_001 = grch38.transcripts_by_name("BRCA2-001")[0]
     # first 50 characters of BRCA2-001:
     #  "GGGCTTGTGGCGCGAGCTTCTGAAACTAGGCGGCAGAGGCGGAGCCGCTG"
     brca2_ref_seq = brca2_001.sequence[:50]
@@ -94,9 +82,8 @@ def test_sequence_key_for_variant_on_transcript_insertion():
 def test_sequence_key_for_variant_on_transcript_substitution_reverse_strand():
     # Replace start codon of TP53-001 with 'CCC', however since this is on
     # reverse strand the variant becomes "CAT">"GGG"
-    tp53_substitution = Variant(
-        "17", 7676592, "CAT", "GGG", ensembl_grch38)
-    tp53_001 = ensembl_grch38.transcripts_by_name("TP53-001")[0]
+    tp53_substitution = Variant("17", 7676592, "CAT", "GGG", grch38)
+    tp53_001 = grch38.transcripts_by_name("TP53-001")[0]
     # Sequence of TP53 around start codon with 10 context nucleotides:
     # In [51]: t.sequence[190-10:190+13]
     # Out[51]: 'GGTCACTGCC_ATG_GAGGAGCCGC'
@@ -115,12 +102,12 @@ def test_sequence_key_for_variant_on_transcript_substitution_reverse_strand():
         sequence_after_variant_locus="GAGGAGCCGC")
     eq_(sequence_key, expected_sequence_key)
 
+
 def test_sequence_key_for_variant_on_transcript_deletion_reverse_strand():
     # delete start codon of TP53-001, which in reverse complement means
     # deleting the sequence "CAT"
-    tp53_deletion = Variant(
-        "17", 7676592, "CAT", "", ensembl_grch38)
-    tp53_001 = ensembl_grch38.transcripts_by_name("TP53-001")[0]
+    tp53_deletion = Variant("17", 7676592, "CAT", "", grch38)
+    tp53_001 = grch38.transcripts_by_name("TP53-001")[0]
     # Sequence of TP53 around start codon with 10 context nucleotides:
     # In [51]: t.sequence[190-10:190+13]
     # Out[51]: 'GGTCACTGCC_ATG_GAGGAGCCGC'
@@ -139,12 +126,12 @@ def test_sequence_key_for_variant_on_transcript_deletion_reverse_strand():
         sequence_after_variant_locus="GAGGAGCCGC")
     eq_(sequence_key, expected_sequence_key)
 
+
 def test_sequence_key_for_variant_on_transcript_insertion_reverse_strand():
     # insert 'CCC' after start codon of TP53-001, which on the reverse
     # complement means inserting "GGG" between "CTC_CAT"
-    tp53_insertion = Variant(
-        "17", 7676589, "CTC", "CTCGGG", ensembl_grch38)
-    tp53_001 = ensembl_grch38.transcripts_by_name("TP53-001")[0]
+    tp53_insertion = Variant("17", 7676589, "CTC", "CTCGGG", grch38)
+    tp53_001 = grch38.transcripts_by_name("TP53-001")[0]
     # Sequence of TP53 around start codon with 10 context nucleotides:
     # In [51]: t.sequence[190-10:190+13]
     # Out[51]: 'GGTCACTGCC_ATG_GAGGAGCCGC'
@@ -184,6 +171,7 @@ def test_reference_sequence_key_hash_and_equality_same_objects():
     eq_(str(rsk1), str(rsk2))
     eq_(repr(rsk1), repr(rsk2))
 
+
 def test_reference_sequence_key_hash_and_equality_different_objects():
     rsk1 = ReferenceSequenceKey(
         strand="+",
@@ -200,12 +188,12 @@ def test_reference_sequence_key_hash_and_equality_different_objects():
     assert str(rsk1) != str(rsk_different_strand)
     assert repr(rsk1) != repr(rsk_different_strand)
 
+
 def test_reference_sequence_key_from_weird_deletion():
     # variant reads into the intron; want to make sure isovar skips over such cases
-    mouse_genome = genome_for_reference_name("grcm38")
-    variant = Variant(
-        "11", 106262686, "GTGAAGG", "", mouse_genome)
-    transcript = mouse_genome.transcript_by_id("ENSMUST00000021049")
+
+    variant = Variant("11", 106262686, "GTGAAGG", "", grcm38)
+    transcript = grcm38.transcript_by_id("ENSMUST00000021049")
     sequence_key = ReferenceSequenceKey.from_variant_and_transcript(
         variant=variant,
         transcript=transcript,
